@@ -3,10 +3,10 @@ package Portable::Config;
 use 5.008;
 use strict;
 use warnings;
-use Carp       ();
-use File::Spec ();
+use Carp            ();
+use File::Spec 3.29 ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 
 
